@@ -255,7 +255,7 @@ typedef struct  _VADecPictureParameterBufferAV1
             uint32_t        color_range                                 : 1;
             uint32_t        subsampling_x                               : 1;
             uint32_t        subsampling_y                               : 1;
-            uint32_t        chroma_sample_position                      : 1;
+            va_deprecated uint32_t        chroma_sample_position        : 1;
             uint32_t        film_grain_params_present                   : 1;
             /** \brief Reserved bytes for future use, must be zero */
             uint32_t        reserved                                    : 16;
@@ -364,7 +364,11 @@ typedef struct  _VADecPictureParameterBufferAV1
     uint8_t                 tile_cols;
     uint8_t                 tile_rows;
 
-    /* specifes the width/height of a tile minus 1 in units of superblocks */
+    /* The width/height of a tile minus 1 in units of superblocks. Though the
+     * maximum number of tiles is 64, since ones of the last tile are computed
+     * from ones of the other tiles and frame_width/height, they are not
+     * necessarily specified.
+     */
     uint16_t                width_in_sbs_minus_1[63];
     uint16_t                height_in_sbs_minus_1[63];
 
@@ -425,7 +429,7 @@ typedef struct  _VADecPictureParameterBufferAV1
     uint8_t                 superres_scale_denominator;
 
     /** \brief Interpolation filter.
-     *  value range [0..9]
+     *  value range [0..4]
      */
     uint8_t                 interp_filter;
 
@@ -459,13 +463,13 @@ typedef struct  _VADecPictureParameterBufferAV1
 
     /** \brief The adjustment needed for the filter level based on
      *  the chosen reference frame.
-     *  value range [-63..63].
+     *  value range [-64..63].
      */
     int8_t                  ref_deltas[8];
 
     /** \brief The adjustment needed for the filter level based on
      *  the chosen mode.
-     *  value range [-63..63].
+     *  value range [-64..63].
      */
     int8_t                  mode_deltas[2];
 
@@ -476,23 +480,23 @@ typedef struct  _VADecPictureParameterBufferAV1
      */
     uint8_t                base_qindex;
     /** \brief Y DC delta from Y AC
-     *  value range [-63..63]
+     *  value range [-64..63]
      */
     int8_t                  y_dc_delta_q;
     /** \brief U DC delta from Y AC
-     *  value range [-63..63]
+     *  value range [-64..63]
      */
     int8_t                  u_dc_delta_q;
     /** \brief U AC delta from Y AC
-     *  value range [-63..63]
+     *  value range [-64..63]
      */
     int8_t                  u_ac_delta_q;
     /** \brief V DC delta from Y AC
-     *  value range [-63..63]
+     *  value range [-64..63]
      */
     int8_t                  v_dc_delta_q;
     /** \brief V AC delta from Y AC
-     *  value range [-63..63]
+     *  value range [-64..63]
      */
     int8_t                  v_ac_delta_q;
 
@@ -559,6 +563,21 @@ typedef struct  _VADecPictureParameterBufferAV1
     uint8_t                 cdef_damping_minus_3;
     /*  value range [0..3]  */
     uint8_t                 cdef_bits;
+
+    /** Encode cdef strength:
+     *
+     * The cdef_y_strengths[] and cdef_uv_strengths[] are expected to be packed
+     * with both primary and secondary strength. The secondary strength is
+     * given in the lower two bits and the primary strength is given in the next
+     * four bits.
+     *
+     * cdef_y_strengths[] & cdef_uv_strengths[] should be derived as:
+     * (cdef_y_strengths[]) = (cdef_y_pri_strength[] << 2) | (cdef_y_sec_strength[] & 0x03)
+     * (cdef_uv_strengths[]) = (cdef_uv_pri_strength[] << 2) | (cdef_uv_sec_strength[] & 0x03)
+     * In which, cdef_y_pri_strength[]/cdef_y_sec_strength[]/cdef_uv_pri_strength[]/cdef_uv_sec_strength[]
+     * are variables defined in AV1 Spec 5.9.19. The cdef_y_strengths[] & cdef_uv_strengths[]
+     * are corresponding to LIBAOM variables cm->cdef_strengths[] & cm->cdef_uv_strengths[] respectively.
+     */
     /*  value range [0..63]  */
     uint8_t                 cdef_y_strengths[8];
     /*  value range [0..63]  */
@@ -629,8 +648,9 @@ typedef struct _VASliceParameterBufferAV1
 
     uint16_t                tile_row;
     uint16_t                tile_column;
-    uint16_t                tg_start;
-    uint16_t                tg_end;
+
+    va_deprecated uint16_t  tg_start;
+    va_deprecated uint16_t  tg_end;
     /** \brief anchor frame index for large scale tile.
      *  index into an array AnchorFrames of the frames that the tile uses
      *  for prediction.
